@@ -351,7 +351,7 @@ gconf_server_load_sources(void)
       /* Try using the default address xml:readwrite:$(HOME)/.gconf */
       addresses = g_slist_append(addresses, g_strconcat("xml:readwrite:", home, "/.gconf", NULL));
 
-      gconf_log(GCL_DEBUG, _("No configuration files found, trying to use the default config source `%s'"), (char *)addresses->data);
+      gconf_log(GCL_DEBUG, _("No configuration files found. Trying to use the default configuration source `%s'"), (char *)addresses->data);
     }
   
   if (addresses == NULL)
@@ -359,7 +359,7 @@ gconf_server_load_sources(void)
       /* We want to stay alive but do nothing, because otherwise every
          request would result in another failed gconfd being spawned.  
       */
-      gconf_log(GCL_ERR, _("No configuration sources in the source path, configuration won't be saved; edit %s%s"), GCONF_CONFDIR, "/path");
+      gconf_log(GCL_ERR, _("No configuration sources in the source path. Configuration won't be saved; edit %s%s"), GCONF_CONFDIR, "/path");
       /* don't request error since there aren't any addresses */
       sources = gconf_sources_new_from_addresses(NULL, NULL);
 
@@ -372,7 +372,7 @@ gconf_server_load_sources(void)
 
       if (error != NULL)
         {
-          gconf_log(GCL_ERR, _("Error loading some config sources: %s"),
+          gconf_log(GCL_ERR, _("Error loading some configuration sources: %s"),
                     error->message);
 
           g_error_free(error);
@@ -384,7 +384,7 @@ gconf_server_load_sources(void)
       g_assert(sources != NULL);
 
       if (sources->sources == NULL)
-        gconf_log(GCL_ERR, _("No config source addresses successfully resolved, can't load or store config data"));
+        gconf_log(GCL_ERR, _("No configuration source addresses successfully resolved. Can't load or store configuration data"));
     
       tmp = sources->sources;
 
@@ -401,7 +401,7 @@ gconf_server_load_sources(void)
 
       /* In this case, some sources may still return TRUE from their writable() function */
       if (!have_writable)
-        gconf_log(GCL_WARNING, _("No writable config sources successfully resolved, may not be able to save some configuration changes"));
+        gconf_log(GCL_WARNING, _("No writable configuration sources successfully resolved. May be unable to save some configuration changes"));
 
         
       /* Install the sources as the default database */
@@ -409,6 +409,10 @@ gconf_server_load_sources(void)
     }
 }
 
+/*
+ * Signal handlers should not log debug messages as this code is non-reentrant.
+ * Please avoid calling gconf_log in this function.
+ */
 static void
 signal_handler (int signo)
 {
@@ -429,15 +433,9 @@ signal_handler (int signo)
   case SIGILL:
     enter_shutdown ();
 #ifndef G_OS_WIN32
-    gconf_log (GCL_ERR,
-               _("Received signal %d, dumping core. Please report a GConf bug."),
-               signo);
     if (g_getenv ("DISPLAY"))
       gconf_handle_segv (signo);
 #else
-    gconf_log (GCL_ERR,
-               _("Received signal %d. Please report a GConf bug."),
-               signo);
     gconf_handle_segv (signo);
 #endif
     abort ();
@@ -455,11 +453,6 @@ signal_handler (int signo)
     /* let the fatal signals interrupt us */
     --in_fatal;
     
-    gconf_log (GCL_ERR,
-               _("Received signal %d, shutting down abnormally. Please file a GConf bug report."),
-               signo);
-
-
     if (gconf_main_is_running ())
       gconf_main_quit ();
     
@@ -471,9 +464,6 @@ signal_handler (int signo)
     /* let the fatal signals interrupt us */
     --in_fatal;
     
-    gconf_log (GCL_INFO,
-               _("Received signal %d, shutting down cleanly"), signo);
-
     if (gconf_main_is_running ())
       gconf_main_quit ();
     break;
@@ -1354,7 +1344,7 @@ gconfd_check_in_shutdown (CORBA_Environment *ev)
       ConfigException* ce;
       
       ce = ConfigException__alloc();
-      ce->message = CORBA_string_dup("config server is currently shutting down");
+      ce->message = CORBA_string_dup("Configuration server is currently shutting down");
       ce->err_no = ConfigInShutdown;
 
       CORBA_exception_set(ev, CORBA_USER_EXCEPTION,
@@ -1587,7 +1577,7 @@ logfile_save (void)
   if (g_rename (tmpfile, logfile) < 0)
     {
       gconf_log (GCL_WARNING,
-                 _("Failed to move new save state file into place: %s"),
+                 _("Failed to move new saved state file into place: %s"),
                  g_strerror (errno));
 
       /* Try to restore old file */
@@ -1719,7 +1709,7 @@ parse_listener_entry (GHashTable *entries,
   if (err != NULL)
     {
       gconf_log (GCL_DEBUG,
-                 "Failed to unquote config source address from saved state file: %s",
+                 "Failed to unquote configuration source address from saved state file: %s",
                  err->message);
 
       g_error_free (err);
@@ -1938,7 +1928,7 @@ restore_client (const gchar *ior)
   
   if (ev._major != CORBA_NO_EXCEPTION)
     {
-      gconf_log (GCL_DEBUG, "Failed to update client in saved state file, probably the client no longer exists");
+      gconf_log (GCL_DEBUG, "Failed to update client in saved state file, the client probably no longer exists");
 
       goto finished;
     }
